==> frogr-0.2.tar.bz2: frogr-0.2/src/frogr-details-dialog.h <==
/*
 * frogr-details-dialog.h -- Picture details dialog
 *
 * Copyright (C) 2009 Mario Sanchez Prada
 * Authors: Mario Sanchez Prada <msanchez@igalia.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef FROGR_DETAILS_DIALOG_H
#define FROGR_DETAILS_DIALOG_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define FROGR_TYPE_DETAILS_DIALOG           (frogr_details_dialog_get_type())
#define FROGR_DETAILS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_CAST(obj, FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialog))
#define FROGR_DETAILS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST(klass, FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialogClass))
#define FROGR_IS_DETAILS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_TYPE(obj, FROGR_TYPE_DETAILS_DIALOG))
#define FROGR_IS_DETAILS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass), FROGR_TYPE_DETAILS_DIALOG))
#define FROGR_DETAILS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialogClass))

typedef struct _FrogrDetailsDialog        FrogrDetailsDialog;
typedef struct _FrogrDetailsDialogClass   FrogrDetailsDialogClass;

struct _FrogrDetailsDialogClass
{
  GtkDialogClass parent_class;
};

struct _FrogrDetailsDialog
{
  GtkDialog parent;
};

GType frogr_details_dialog_get_type (void) G_GNUC_CONST;

FrogrDetailsDialog *frogr_details_dialog_new (GtkWindow *parent,
                                              GSList *fpictures);

void frogr_details_dialog_show (FrogrDetailsDialog *fdetailsdialog);

G_END_DECLS  /* FROGR_DETAILS_DIALOG_H */

#endif

==> frogr-0.3.tar.bz2: frogr-0.3/src/frogr-details-dialog.h <==
/*
 * frogr-details-dialog.h -- Picture details dialog
 *
 * Copyright (C) 2009, 2010 Mario Sanchez Prada
 * Authors: Mario Sanchez Prada <msanchez@igalia.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 */

#ifndef FROGR_DETAILS_DIALOG_H
#define FROGR_DETAILS_DIALOG_H

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define FROGR_TYPE_DETAILS_DIALOG           (frogr_details_dialog_get_type())
#define FROGR_DETAILS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_CAST(obj, FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialog))
#define FROGR_DETAILS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST(klass, FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialogClass))
#define FROGR_IS_DETAILS_DIALOG(obj)           (G_TYPE_CHECK_INSTANCE_TYPE(obj, FROGR_TYPE_DETAILS_DIALOG))
#define FROGR_IS_DETAILS_DIALOG_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE((klass), FROGR_TYPE_DETAILS_DIALOG))
#define FROGR_DETAILS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FROGR_TYPE_DETAILS_DIALOG, FrogrDetailsDialogClass))

typedef struct _FrogrDetailsDialog        FrogrDetailsDialog;
typedef struct _FrogrDetailsDialogClass   FrogrDetailsDialogClass;

struct _FrogrDetailsDialogClass
{
  GtkDialogClass parent_class;
};

struct _FrogrDetailsDialog
{
  GtkDialog parent;
};

GType frogr_details_dialog_get_type (void) G_GNUC_CONST;

void frogr_details_dialog_show (GtkWindow *parent, GSList *fpictures);

G_END_DECLS  /* FROGR_DETAILS_DIALOG_H */

#endif
